@@ -8,7 +8,7 @@
 # or in the "LICENSE.txt" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES
 # OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions and
 # limitations under the License.
-from future.moves.collections import OrderedDict
+from collections import OrderedDict
 
 import boto3
 
@@ -27,6 +27,8 @@ from pcluster.config.cfn_param_types import (
     EFSCfnSection,
     ExtraJsonCfnParam,
     FloatCfnParam,
+    FSxDNSNameParam,
+    FSxMountNameParam,
     HeadNodeAvailabilityZoneCfnParam,
     HeadNodeInstanceTypeCfnParam,
     IntCfnParam,
@@ -57,7 +59,6 @@ from pcluster.config.param_types import Visibility
 from pcluster.config.update_policy import UpdatePolicy
 from pcluster.config.validators import (
     architecture_os_validator,
-    base_os_validator,
     cluster_type_validator,
     cluster_validator,
     compute_instance_type_validator,
@@ -103,6 +104,8 @@ from pcluster.config.validators import (
     queue_compute_type_validator,
     queue_settings_validator,
     queue_validator,
+    region_validator,
+    s3_bucket_region_validator,
     s3_bucket_uri_validator,
     s3_bucket_validator,
     scheduler_validator,
@@ -110,9 +113,15 @@ from pcluster.config.validators import (
     tags_validator,
     url_validator,
 )
-from pcluster.constants import CIDR_ALL_IPS, FSX_HDD_THROUGHPUT, FSX_SSD_THROUGHPUT, SUPPORTED_ARCHITECTURES
+from pcluster.constants import (
+    CIDR_ALL_IPS,
+    FSX_HDD_THROUGHPUT,
+    FSX_SSD_THROUGHPUT,
+    SUPPORTED_ARCHITECTURES,
+    SUPPORTED_OSS,
+)
 
-CLUSTER_COMMON_VALIDATORS = [duplicate_shared_dir_validator]
+CLUSTER_COMMON_VALIDATORS = [duplicate_shared_dir_validator, region_validator]
 # This file contains a definition of all the sections and the parameters configurable by the user
 # in the configuration file.
 
@@ -151,7 +160,7 @@ ALLOWED_VALUES = {
     "efs_fs_id": r"^fs-[0-9a-z]{8}$|^fs-[0-9a-z]{17}|NONE$",
     "file_path": r"^\/?[^\/.\\][^\/\\]*(\/[^\/.\\][^\/]*)*$",
     "fsx_fs_id": r"^fs-[0-9a-z]{17}|NONE$",
-    "greater_than_25": r"^([0-9]+[0-9]{2}|[3-9][0-9]|2[5-9])$",
+    "greater_than_35": r"^([1-9][0-9]{2,}|[4-9][0-9]|3[5-9])$",
     "security_group_id": r"^sg-[0-9a-z]{8}$|^sg-[0-9a-z]{17}$",
     "snapshot_id": r"^snap-[0-9a-z]{8}$|^snap-[0-9a-z]{17}$",
     "subnet_id": r"^subnet-[0-9a-z]{8}$|^subnet-[0-9a-z]{17}$",
@@ -164,7 +173,8 @@ ALLOWED_VALUES = {
     "architectures": SUPPORTED_ARCHITECTURES,
     "fsx_auto_import_policy": ["NEW", "NEW_CHANGED"],
     "fsx_storage_type": ["SSD", "HDD"],
-    "fsx_drive_cache_type": ["READ"]
+    "fsx_drive_cache_type": ["READ"],
+    "fsx_data_compression_type": ["LZ4"]
 }
 
 AWS = {
@@ -319,8 +329,7 @@ EBS = {
     "max_resources": 5,
     "validators": [ebs_volume_type_size_validator, ebs_volume_iops_validator, ebs_volume_size_snapshot_validator,
                    ebs_volume_throughput_validator],
-    "params": OrderedDict([  # Use OrderedDict because the in python 3.5 a dict is not ordered by default, need it in
-        # the test of hit converter
+    "params": OrderedDict([
         ("shared_dir", {
             "allowed_values": ALLOWED_VALUES["file_path"],
             "cfn_param_mapping": "SharedDir",
@@ -569,7 +578,24 @@ FSX = {
                 "default": "NONE",
                 "allowed_values": ALLOWED_VALUES["fsx_drive_cache_type"],
                 "update_policy": UpdatePolicy.UNSUPPORTED
-            })
+            }),
+            ("existing_mount_name", {
+                "type": FSxMountNameParam,
+                "default": "NONE",
+                "update_policy": UpdatePolicy.IGNORED,
+                "visibility": Visibility.PRIVATE,
+            }),
+            ("existing_dns_name", {
+                "type": FSxDNSNameParam,
+                "default": "NONE",
+                "update_policy": UpdatePolicy.IGNORED,
+                "visibility": Visibility.PRIVATE,
+            }),
+            ("data_compression_type", {
+                "default": "NONE",
+                "allowed_values": ALLOWED_VALUES["fsx_data_compression_type"],
+                "update_policy": UpdatePolicy.SUPPORTED
+            }),
         ]
     )
 }
@@ -683,6 +709,13 @@ COMPUTE_RESOURCE = {
             "visibility": Visibility.PRIVATE,
             "default": 0
         }),
+        ("gpu_type", {
+            "type": JsonParam,
+            # This param is managed automatically
+            "update_policy": UpdatePolicy.IGNORED,
+            "visibility": Visibility.PRIVATE,
+            "default": "no_gpu_type"
+        }),
         ("network_interfaces", {
             "type": IntJsonParam,
             # This param is managed automatically
@@ -699,10 +732,8 @@ COMPUTE_RESOURCE = {
         }),
         ("enable_efa_gdr", {
             "type": BooleanJsonParam,
-            # This param is managed automatically
-            "update_policy": UpdatePolicy.IGNORED,
-            "visibility": Visibility.PRIVATE,
-            "default": False
+            "validators": [efa_gdr_validator],
+            "update_policy": UpdatePolicy.IGNORED
         }),
         ("disable_hyperthreading", {
             "type": BooleanJsonParam,
@@ -741,7 +772,8 @@ QUEUE = {
         }),
         ("enable_efa_gdr", {
             "type": BooleanJsonParam,
-            "update_policy": UpdatePolicy.COMPUTE_FLEET_STOP,
+            "validators": [efa_gdr_validator],
+            "update_policy": UpdatePolicy.IGNORED,
         }),
         ("disable_hyperthreading", {
             "type": BooleanJsonParam,
@@ -772,7 +804,6 @@ CLUSTER_COMMON_PARAMS = [
     }),
     ("key_name", {
         "cfn_param_mapping": "KeyName",
-        "required": True,
         "validators": [ec2_key_pair_validator],
         "update_policy": UpdatePolicy.UNSUPPORTED
     }),
@@ -792,8 +823,8 @@ CLUSTER_COMMON_PARAMS = [
     }),
     ("master_root_volume_size", {
         "type": IntCfnParam,
-        "default": 25,
-        "allowed_values": ALLOWED_VALUES["greater_than_25"],
+        "default": 35,
+        "allowed_values": ALLOWED_VALUES["greater_than_35"],
         "cfn_param_mapping": "MasterRootVolumeSize",
         "update_policy": UpdatePolicy(
             UpdatePolicy.UNSUPPORTED,
@@ -804,16 +835,16 @@ CLUSTER_COMMON_PARAMS = [
     ("base_os", {
         "type": BaseOSCfnParam,
         "cfn_param_mapping": "BaseOS",
-        "allowed_values": ["alinux", "alinux2", "ubuntu1604", "ubuntu1804", "centos7", "centos8"],
-        "validators": [base_os_validator, architecture_os_validator],
+        "allowed_values": SUPPORTED_OSS,
+        "validators": [architecture_os_validator],
         "required": True,
         "update_policy": UpdatePolicy.UNSUPPORTED
     }),
     # Compute fleet
     ("compute_root_volume_size", {
         "type": IntCfnParam,
-        "default": 25,
-        "allowed_values": ALLOWED_VALUES["greater_than_25"],
+        "default": 35,
+        "allowed_values": ALLOWED_VALUES["greater_than_35"],
         "cfn_param_mapping": "ComputeRootVolumeSize",
         "update_policy": UpdatePolicy.COMPUTE_FLEET_STOP
     }),
@@ -857,7 +888,6 @@ CLUSTER_COMMON_PARAMS = [
     }),
     ("enable_efa_gdr", {
         "allowed_values": ["compute"],
-        "cfn_param_mapping": "EFAGDR",
         "validators": [efa_gdr_validator],
         "update_policy": UpdatePolicy.UNSUPPORTED
     }),
@@ -1021,7 +1051,7 @@ CLUSTER_COMMON_PARAMS = [
     }),
     ("cluster_resource_bucket", {
         "cfn_param_mapping": "ResourcesS3Bucket",
-        "validators": [s3_bucket_validator],
+        "validators": [s3_bucket_validator, s3_bucket_region_validator],
         "update_policy": UpdatePolicy.READ_ONLY_RESOURCE_BUCKET,
     }),
     ("iam_lambda_role", {
@@ -1073,7 +1103,7 @@ CLUSTER_SIT = {
                 "type": QueueSizeCfnParam,
                 "default": 10,
                 "cfn_param_mapping": "MaxSize",
-                "update_policy": UpdatePolicy.SUPPORTED
+                "update_policy": UpdatePolicy.MAX_QUEUE_SIZE
             }),
             ("maintain_initial_size", {
                 "type": MaintainInitialSizeCfnParam,
